@@ -84,7 +84,7 @@ class Identity(Service):
         )
 
     def user_logout(self, refresh_token_ids='', disable_login=''):
-        """ Logs user out via /users/{user_id}/logout endpoint
+        """ Logs user out via /user/{user_id}/logout endpoint
             refresh_token_ids : string
                 A comma separated list of refresh token IDs.
             disable_login : string
